Summary:        The Reliable, High Performance TCP/HTTP Load Balancer
Name:           haproxy
Version:        2.6.9
Release:        5%{?dist}
License:        GPLv2+
URL:            http://www.haproxy.org/
Source0:        %{url}/download/2.6/src/haproxy-%{version}.tar.gz
Source1:        %{name}.service
Source2:        %{name}.cfg
Source3:        %{name}.logrotate
Source4:        %{name}.sysconfig
Source5:        %{name}.sysusers
Source6:        halog.1

Patch0001:      0001-BUG-MAJOR-http-reject-any-empty-content-length-heade.patch

BuildRequires:  gcc make
BuildRequires:  lua-devel pcre2-devel openssl-devel systemd-devel systemd systemd-rpm-macros
Requires(pre):  shadow-utils
%{?systemd_requires}

%description
HAProxy is a free, very fast and reliable reverse-proxy
offering high availability, load balancing, and proxying
for TCP and HTTP-based applications. It is particularly
suited for very high traffic web sites and powers a
significant portion of the world's most visited ones. 

%prep
%autosetup -p1

%build
%make_build \
  CPU="generic" \
  TARGET="linux-glibc" \
  USE_OPENSSL=1 USE_PCRE2=1 \
  USE_SLZ=1 \
  USE_LUA=1 LUA_LIB_NAME=lua-5.4 \
  USE_CRYPT_H=1 \
  USE_SYSTEMD=1 \
  USE_LINUX_TPROXY=1 \
  USE_GETADDRINFO=1 \
  USE_PROMEX=1 \
  DEFINE=-DMAX_SESS_STKCTR=12 \
  ADDINC="%{build_cflags}" \
  ADDLIB="%{build_ldflags}"

make admin/halog/halog ADDINC="%{build_cflags}" ADDLIB="%{build_ldflags}"

pushd admin/iprange
make OPTIMIZE="%{build_cflags}" LDFLAGS="%{build_ldflags}"
popd

%install
make install-bin DESTDIR=%{buildroot} PREFIX=%{_prefix} TARGET="linux2628"
make install-man DESTDIR=%{buildroot} PREFIX=%{_prefix}
install -p -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
install -p -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/haproxy/%{name}.cfg
install -p -D -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -p -D -m 0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -p -D -m 0644 %{SOURCE5} %{buildroot}%{_sysusersdir}/%{name}.conf
install -p -D -m 0644 %{SOURCE6} %{buildroot}%{_mandir}/man1/halog.1
install -d -m 0755 %{buildroot}%{_localstatedir}/lib/haproxy
install -d -m 0755 %{buildroot}%{_datadir}/haproxy
install -d -m 0755 %{buildroot}%{_sysconfdir}/haproxy/conf.d
install -d -m 0755 %{buildroot}%{_bindir}
install -p -m 0755 ./admin/halog/halog %{buildroot}%{_bindir}/halog
install -p -m 0755 ./admin/iprange/iprange %{buildroot}%{_bindir}/iprange
install -p -m 0755 ./admin/iprange/ip6range %{buildroot}%{_bindir}/ip6range

for httpfile in $(find ./examples/errorfiles/ -type f) 
do
    install -p -m 0644 $httpfile %{buildroot}%{_datadir}/haproxy
done

rm -rf ./examples/errorfiles/

find ./examples/* -type f ! -name "*.cfg" -delete

for textfile in $(find ./ -type f -name '*.txt')
do
    mv $textfile $textfile.old
    iconv --from-code ISO8859-1 --to-code UTF-8 --output $textfile $textfile.old
    rm -f $textfile.old
done

%pre
%sysusers_create_compat %{SOURCE5}

%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service

%files
%license LICENSE
%doc CHANGELOG README VERSION doc/* examples/*
%{_bindir}/halog
%{_bindir}/iprange
%{_bindir}/ip6range
%dir %{_datadir}/haproxy
%{_datadir}/haproxy/*
%dir %{_localstatedir}/lib/haproxy
%{_sbindir}/%{name}
%dir %{_sysconfdir}/haproxy
%dir %{_sysconfdir}/haproxy/conf.d
%config(noreplace) %{_sysconfdir}/haproxy/%{name}.cfg
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_sysusersdir}/%{name}.conf
%{_unitdir}/%{name}.service
%{_mandir}/man1/*

%changelog
* Fri Oct 20 2023 Miaojun Dong <zoedong@tencent.com> - 2.6.9-5
- Fix CVE-2023-40225

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.9-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.9-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.9-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Mar 09 2023 Miaojun Dong <zoedong@tencent.com> - 2.6.9-1
- initial build
